# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: object_detection/protos/flexible_grid_anchor_generator.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<object_detection/protos/flexible_grid_anchor_generator.proto\x12\x17object_detection.protos\"|\n\x1b\x46lexibleGridAnchorGenerator\x12\x38\n\x0b\x61nchor_grid\x18\x01 \x03(\x0b\x32#.object_detection.protos.AnchorGrid\x12#\n\x15normalize_coordinates\x18\x02 \x01(\x08:\x04true\"\x97\x01\n\nAnchorGrid\x12\x12\n\nbase_sizes\x18\x01 \x03(\x02\x12\x15\n\raspect_ratios\x18\x02 \x03(\x02\x12\x15\n\rheight_stride\x18\x03 \x01(\r\x12\x14\n\x0cwidth_stride\x18\x04 \x01(\r\x12\x18\n\rheight_offset\x18\x05 \x01(\r:\x01\x30\x12\x17\n\x0cwidth_offset\x18\x06 \x01(\r:\x01\x30')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'object_detection.protos.flexible_grid_anchor_generator_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FLEXIBLEGRIDANCHORGENERATOR._serialized_start=89
  _FLEXIBLEGRIDANCHORGENERATOR._serialized_end=213
  _ANCHORGRID._serialized_start=216
  _ANCHORGRID._serialized_end=367
# @@protoc_insertion_point(module_scope)
